==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteListFluent<A extends TCPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,TCPRoute item);
  public A setToItems(Integer index,TCPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public A addAllToItems(Collection<TCPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public A removeAllFromItems(Collection<TCPRoute> items);
  public A removeMatchingFromItems(Predicate<TCPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRoute> getItems();
  public List<TCPRoute> buildItems();
  public TCPRoute buildItem(Integer index);
  public TCPRoute buildFirstItem();
  public TCPRoute buildLastItem();
  public TCPRoute buildMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public A withItems(List<TCPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public Boolean hasItems();
  public TCPRouteListFluent.ItemsNested<A> addNewItem();
  public TCPRouteListFluent.ItemsNested<A> addNewItemLike(TCPRoute item);
  public TCPRouteListFluent.ItemsNested<A> setNewItemLike(Integer index,TCPRoute item);
  public TCPRouteListFluent.ItemsNested<A> editItem(Integer index);
  public TCPRouteListFluent.ItemsNested<A> editFirstItem();
  public TCPRouteListFluent.ItemsNested<A> editLastItem();
  public TCPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,TCPRouteFluent<TCPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteListFluent<A extends TCPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,TCPRoute item);
  public A setToItems(int index,TCPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public A addAllToItems(Collection<TCPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public A removeAllFromItems(Collection<TCPRoute> items);
  public A removeMatchingFromItems(Predicate<TCPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRoute> getItems();
  public List<TCPRoute> buildItems();
  public TCPRoute buildItem(int index);
  public TCPRoute buildFirstItem();
  public TCPRoute buildLastItem();
  public TCPRoute buildMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public A withItems(List<TCPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRoute... items);
  public Boolean hasItems();
  public TCPRouteListFluent.ItemsNested<A> addNewItem();
  public TCPRouteListFluent.ItemsNested<A> addNewItemLike(TCPRoute item);
  public TCPRouteListFluent.ItemsNested<A> setNewItemLike(int index,TCPRoute item);
  public TCPRouteListFluent.ItemsNested<A> editItem(int index);
  public TCPRouteListFluent.ItemsNested<A> editFirstItem();
  public TCPRouteListFluent.ItemsNested<A> editLastItem();
  public TCPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<TCPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,TCPRouteFluent<TCPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
